import * as Konva from "konva";
import { ICircle } from "./circle";
import { IArrow } from "./arrow";
import { IImage } from "./image";
import { IPolygon } from "./polygon";
import { IRectangle } from "./rectangle";
export interface IThisParam {
    layer: Konva.Layer;
    stage: Konva.Stage;
    scale: number;
}
declare type IShape<T> = T extends Konva.Arrow ? Partial<IArrow> : T extends Konva.Circle ? Partial<ICircle> : T extends Konva.Image ? Partial<IImage> : T extends Konva.Rect ? Partial<IRectangle> : T extends Konva.Shape ? Partial<IPolygon> : {};
declare enum EventTypes {
    "mousedown" = 0,
    "mouseup" = 1,
    "touchstart" = 2,
    "touchend" = 3
}
export declare class R2dObject {
    private readonly nativeObject;
    getNativeObject: () => Konva.Shape;
    private readonly layer;
    private readonly stage;
    private readonly scale;
    constructor(nativeObject: Konva.Shape, thisParam: IThisParam);
    destroy(): void;
    intersects(object: R2dObject): boolean;
    show(): void;
    hide(): void;
    on(events: Array<keyof typeof EventTypes>, callback: (e: {
        x: number;
        y: number;
    }) => void): void;
    off(events: Array<keyof typeof EventTypes>): void;
    protected internalUpdateAppearance<T>(args: IShape<T>): void;
}
export {};
