import * as ROSLib from "roslib";
import { CircleObject, ICircle } from "./helpers/circle";
import { IRectangle, RectangleObject } from "./helpers/rectangle";
import { ArrowObject, IArrow } from "./helpers/arrow";
import { IImageAsync, IImageAsyncReturnSuccess, IImageSync, ImageObject } from "./helpers/image";
import { IMap, IMapReturnSuccess } from "./helpers/map";
import { IPolygon, PolygonObject } from "./helpers/polygon";
import { R2dObject } from "./helpers/R2dObject";
interface IR2d {
    container: HTMLElement;
    zoom: boolean;
    pan: boolean;
    scale: number;
    ros: IRosBridgeURL | IRos;
}
interface IAddMap {
    image: ImageObject;
    info: {
        naturalHeight: number;
        origin: number[];
        resolution: number;
    };
}
interface IPoseWithTopic {
    object: R2dObject;
    topic: string;
    queueLength?: number;
    throttleRate?: number;
}
interface IPoseWithUpdater {
    object: R2dObject;
}
interface IHeader {
    frame_id: "map";
    seq: number;
    stamp: {
        secs: number;
        nsecs: number;
    };
}
interface Ixyz {
    x: number;
    y: number;
    z: number;
}
export interface IPoseMsg {
    header: IHeader;
    pose: {
        position: Ixyz;
        orientation: Ixyz & {
            w: number;
        };
    };
}
export interface IRosBridgeURL {
    url: string;
}
export declare type IRos = ROSLib.Ros;
interface IStaticObject {
    object: R2dObject;
    x: number;
    y: number;
    rotationInDegClockwise?: number;
}
interface IPath {
    points: Array<{
        x: number;
        y: number;
    }>;
    color: string;
    width: number;
    tension?: number;
}
export default class R2d {
    private readonly container;
    private readonly stage;
    private readonly zoom;
    private readonly pan;
    private readonly scale;
    private readonly ros;
    private readonly mapLayer;
    private readonly objectsLayer;
    readonly createMap: (args: IMap) => Promise<IMapReturnSuccess>;
    readonly createCircle: (args: ICircle) => CircleObject;
    readonly createRectangle: (args: IRectangle) => RectangleObject;
    readonly createArrow: (args: IArrow) => ArrowObject;
    readonly createImageSync: (args: IImageSync) => ImageObject;
    readonly createImageAsync: (args: IImageAsync) => Promise<IImageAsyncReturnSuccess>;
    readonly createPolygon: (args: IPolygon & {
        points: Array<{
            x: number;
            y: number;
        }>;
    }) => PolygonObject;
    constructor(args: IR2d);
    changePan: (enable: boolean) => void;
    addMap: (mapObject: IAddMap) => {
        destroy: () => void;
        hide: () => void;
        show: () => void;
    };
    addPoseWithUpdater: (pose: IPoseWithUpdater) => {
        updatePose: (poseArg: {
            position: Ixyz;
            orientation: Ixyz & {
                w: number;
            };
        }) => void;
        destroy: () => void;
    };
    addPoseWithTopic: (pose: IPoseWithTopic) => {
        destroy: () => void;
    };
    private moveObjectForPose;
    addStaticObject: (args: IStaticObject) => {
        destroy: () => void;
        hide: () => void;
        show: () => void;
    };
    addPath: (args: IPath) => {
        destroy: () => void;
        hide: () => void;
        show: () => void;
    };
}
export {};
