import { isNil } from "lodash";
import * as Konva from "konva";
import { IThisParam, R2dObject } from "./R2dObject";

export interface IArrow {
  pointerWidth: number;
  pointerLength: number;
  color: string;
  border?: number;
  borderColor?: string;
  opacity?: number;
}

export class ArrowObject extends R2dObject {
  public readonly identifier = "arrow";
  constructor(args: Konva.ArrowConfig, thisParam: IThisParam) {
    super(new Konva.Arrow(args), thisParam);
  }
  public updateAppearance(args: Partial<IArrow>) {
    super.internalUpdateAppearance<Konva.Arrow>(args);
  }
}

function arrow(this: IThisParam, args: IArrow) {
  return new ArrowObject(
    {
      points: [0, 0, args.pointerLength * 2, 0],
      pointerWidth: args.pointerWidth,
      pointerLength: args.pointerLength,
      fill: args.color,
      strokeEnabled: isNil(args.border) ? false : args.border !== 0,
      strokeWidth: !isNil(args.border) ? args.border : 0,
      stroke: !isNil(args.borderColor) ? args.borderColor : "black",
      opacity: !isNil(args.opacity) ? args.opacity : 1,
      x: this.stage.width() / 2,
      y: this.stage.height() / 2
    },
    this
  );
}

export default arrow;
