import { isNil } from "lodash";
import * as Konva from "konva";
import { IThisParam, R2dObject } from "./R2dObject";

export interface ICircle {
  radius: number;
  color: string;
  border?: number;
  borderColor?: string;
  opacity?: number;
}

export class CircleObject extends R2dObject {
  public readonly identifier = "circle";
  constructor(args: Konva.CircleConfig, thisParam: IThisParam) {
    super(new Konva.Circle(args), thisParam);
  }
  public updateAppearance(args: Partial<ICircle>) {
    super.internalUpdateAppearance<Konva.Circle>(args);
  }
}

function circle(this: IThisParam, args: ICircle) {
  return new CircleObject(
    {
      radius: args.radius,
      fill: args.color,
      strokeEnabled: isNil(args.border) ? false : args.border !== 0,
      strokeWidth: !isNil(args.border) ? args.border : 0,
      stroke: !isNil(args.borderColor) ? args.borderColor : "black",
      opacity: !isNil(args.opacity) ? args.opacity : 1,
      x: this.stage.width() / 2,
      y: this.stage.height() / 2
    },
    this
  );
}

export default circle;
