import { ImageObject, imageSync } from "./image";
import { IThisParam } from "./R2dObject";

export interface IMap {
  path: string;
  info: {
    origin: number[];
    resolution: number;
  };
}

export interface IMapReturnSuccess {
  image: ImageObject;
  info: IMap["info"] & { naturalHeight: number };
}

function drawableMap(this: IThisParam, args: IMap) {
  const { path, info } = args;
  const image = new Image();
  image.src = path;
  return new Promise<IMapReturnSuccess>(resolve => {
    const konvaImage = imageSync.bind(this)({
      image
    }) as ImageObject;
    image.onload = () =>
      resolve({
        image: konvaImage,
        info: {
          ...info,
          naturalHeight: image.naturalHeight
        }
      });
    image.onerror = () => {
      throw new Error("error loading image");
    };
  });
}

export default drawableMap;
