import { isNil, map } from "lodash";
import * as Konva from "konva";
import { IThisParam, R2dObject } from "./R2dObject";

export interface IPolygon {
  color: string;
  border?: number;
  borderColor?: string;
  opacity?: number;
}

export class PolygonObject extends R2dObject {
  public readonly identifier = "polygon";
  constructor(args: Konva.ShapeConfig, thisParam: IThisParam) {
    super(new Konva.Shape(args), thisParam);
  }
  public updateAppearance(args: Partial<IPolygon>) {
    super.internalUpdateAppearance<Konva.Shape>(args);
  }
}

function polygon(
  this: IThisParam,
  args: IPolygon & { points: Array<{ x: number; y: number }> }
) {
  if (args.points.length < 3) {
    throw new Error("at least 3 points are required for the polygon");
  }
  return new PolygonObject(
    {
      sceneFunc(context: Konva.Context) {
        context.beginPath();

        const firstPoint = args.points[0];
        context.moveTo(-1 * firstPoint.x, firstPoint.y);
        map(args.points, (point, index) => {
          if (index === 0) {
            return;
          }
          context.lineTo(-1 * point.x, point.y);
        });

        context.closePath();
        context.fillStrokeShape(this);
      },
      fill: args.color,
      x: -1 * args.points[0].x,
      y: args.points[0].y,
      offset: {
        x: -1 * args.points[0].x,
        y: args.points[0].y
      },
      strokeEnabled: isNil(args.border) ? false : args.border !== 0,
      strokeWidth: !isNil(args.border) ? args.border : 0,
      stroke: !isNil(args.borderColor) ? args.borderColor : "black",
      opacity: !isNil(args.opacity) ? args.opacity : 1
    },
    this
  );
}

export default polygon;
