import { isNil } from "lodash";
import * as Konva from "konva";
import { IThisParam, R2dObject } from "./R2dObject";

export interface IRectangle {
  width: number;
  height: number;
  color: string;
  border?: number;
  borderColor?: string;
  opacity?: number;
}

export class RectangleObject extends R2dObject {
  public readonly identifier = "rectangle";
  constructor(args: Konva.RectConfig, thisParam: IThisParam) {
    super(new Konva.Rect(args), thisParam);
  }
  public updateAppearance(args: Partial<IRectangle>) {
    super.internalUpdateAppearance<Konva.Rect>(args);
  }
}

function rectangle(this: IThisParam, args: IRectangle) {
  return new RectangleObject(
    {
      width: args.width,
      height: args.height,
      fill: args.color,
      offsetX: args.width / 2,
      offsetY: args.height / 2,
      strokeEnabled: isNil(args.border) ? false : args.border !== 0,
      strokeWidth: !isNil(args.border) ? args.border : 0,
      stroke: !isNil(args.borderColor) ? args.borderColor : "black",
      opacity: !isNil(args.opacity) ? args.opacity : 1,
      x: this.stage.width() / 2,
      y: this.stage.height() / 2
    },
    this
  );
}

export default rectangle;
